pub struct RunConfig {
pub runid: u32,
pub is_active: bool,
pub nevents: u32,
pub nseconds: u32,
pub tof_op_mode: TofOperationMode,
pub trigger_poisson_rate: u32,
pub trigger_fixed_rate: u32,
pub data_type: DataType,
pub rb_buff_size: Option<u16>,
pub rb_buff_empty_interval: Option<f32>,
pub rb_buff_strategy_smart: bool,
}Expand description
Readoutboard configuration for a specific run
Fields
runid: u32an unique identifier for this run
is_active: boolstart/stop run
nevents: u32limit run to number of events
nseconds: u32limit run time to number of seconds
tof_op_mode: TofOperationModetof operation mode - either “StreamAny”, “RequestReply” or “RBHighThroughput”
trigger_poisson_rate: u32if different from 0, activate RB self trigger in poisson mode
trigger_fixed_rate: u32if different from 0, activate RB self trigger with fixed rate setting
data_type: DataTypeEither “Physics” or a calibration related data type, e.g. “VoltageCalibration”.
rb_buff_size: Option<u16>The value when the readout of the RB buffers is triggered. This number is in size of full events, which correspond to 18530 bytes. Maximum buffer size is a bit more than 3000 events. Smaller buffer allows for a more snappy reaction, but might require more CPU resources (on the board)
rb_buff_empty_interval: Option<f32>The time interval we want to empty the readoutboard buffers
rb_buff_strategy_smart: boolThis will set the RB to figure it out by itself
Implementations